@@ -121,6 +121,8 @@ MAN_OPT_COMMON = ("""\
     --clean         __Skip loading the default configuration file.
     --signup        __Interactively sign up for pagekite.net service.
     --defaults      __Set defaults for use with pagekite.net service.
+    --whitelabel=D  __Set defaults for pagekite.net white-labels.
+    --whitelabels=D __Set defaults for pagekite.net white-labels (with TLS).
     --nocrashreport __Don't send anonymous crash reports to pagekite.net.
 """)
 MAN_OPT_BACKEND = ("""\
@@ -181,6 +183,11 @@ MAN_OPT_BACKEND = ("""\
             this option is repeated, any of the named certificates will be
             accepted, but the first will be preferred.
 
+    --fe_nocertcheck
+            Connect using SSL/TLS, but do not verify the remote certificate.
+            This is largely insecure but still thwarts passive attacks and
+            prevents routers and firewalls from corrupting the PageKite tunnel.
+
     --ca_certs</b>=<a>/path/to/file</a> __
             Path to your trusted root SSL certificates file.
 
@@ -319,7 +326,7 @@ MAN_SECURITY = ("""\
     For more, please visit: <https://pagekite.net/support/security/>
 """)
 MAN_LICENSE = ("""\
-    Copyright 2010-2015, the Beanstalks Project ehf. and Bjarni R. Einarsson.
+    Copyright 2010-2016, the Beanstalks Project ehf. and Bjarni R. Einarsson.
 
     This program is free software: you can redistribute it and/or modify it
     under the terms of the GNU Affero General Public License as published by
